@@ -10,7 +10,7 @@ complete.mids.nmi <- function( x , action = c(1,1) ){
 	if ( x$type == "mice.1chain" ){
 		data <- complete.mids.1chain( x$imp[[ action[1] ]] , action = action[2] )
 	}							
-	base::return(data)					
+	return(data)					
 }
 #######################################################
 
@@ -20,4 +20,4 @@ complete.mids.nmi <- function( x , action = c(1,1) ){
 complete.mids.1chain <- function( x , action = 1 ){
     mice::complete( x$midsobj , action=action )
 }
-#######################################################
\ No newline at end of file
+#######################################################
