@@ -8,10 +8,10 @@ load.data <- function( filename , type="Rdata" , path=getwd() ,
 	dir <- path
 	file <- filename
 	
-	i1 <- grep.vec( base::c("Rdata" , "csv" , "csv2" , "table" , "sav" ) , 
+	i1 <- grep.vec( c("Rdata" , "csv" , "csv2" , "table" , "sav" ) , 
 					file ,  "OR" )$x
-	if ( base::length(i1) == 0 ){							
-		files <- base::list.files( dir , filename )			
+	if ( length(i1) == 0 ){							
+		files <- list.files( dir , filename )			
 		files <- grep.vec( filename , files , "AND")$x
 	} else {
 		files <- file
@@ -21,8 +21,8 @@ load.data <- function( filename , type="Rdata" , path=getwd() ,
 		files <- grep.vec( c("dat","txt") , files , "OR" )$x
 		type1 <- "dat"
 	}		
-	files <- base::grep( base::gsub("csv2","csv" , type1) , files , value=TRUE)
-	file <- base::max(files)
+	files <- grep( gsub("csv2","csv" , type1) , files , value=TRUE)
+	file <- max(files)
 	cat( paste0( "*** Load " , file , "\n"))
 
     #*** Rdata objects	
@@ -52,6 +52,6 @@ load.data <- function( filename , type="Rdata" , path=getwd() ,
 				to.data.frame=TRUE , use.value.labels=FALSE , ... )
 		}			
 	}				
-	base::return(dat4)
+	return(dat4)
 }
-#########################################################################			
\ No newline at end of file
+#########################################################################			
