@@ -5,18 +5,18 @@ ma.wtd.aux.data <- function(data , weights , vars = NULL ){
     #*****
 	
 	is_dfr <- TRUE		# default is class data frame
-	if ( base::is.vector(data) ){
-		data <- base::data.frame( "Var" = data)
+	if ( is.vector(data) ){
+		data <- data.frame( "Var" = data)
 		is_dfr <- TRUE
 	}
 			
 	#---- mids or mids.1chain
-	if ( base::class(data) %in% base::c("mids","mids.1chain","mids.nmi") ){
+	if ( class(data) %in% c("mids","mids.1chain","mids.nmi") ){
 		data <- mids2datlist( data )
 	}		
 	
 	#----- NestedImputationList
-	if ( base::class(data) == "NestedImputationList" ){
+	if ( class(data) == "NestedImputationList" ){
 		is_dfr <- FALSE
 		data <- data$imputations
 		class(data) <- "nested.datlist"
@@ -24,23 +24,23 @@ ma.wtd.aux.data <- function(data , weights , vars = NULL ){
 		
 	#--------------------
 	# conversion in case of a nested datalist	
-	if ( base::class(data) == "nested.datlist" ){
+	if ( class(data) == "nested.datlist" ){
 		is_dfr <- FALSE
 		data <- nesteddatlist2datlist(data)
 	}											
 						
 	#---- imputationList
-	if ( base::class(data) == "imputationList" ){
+	if ( class(data) == "imputationList" ){
 		data <- data$imputations
-		base::class(data) <- "datlist"
+		class(data) <- "datlist"
 	}
 	
 	#--------------------
 	# conversion in case of a datlist
-	if ( base::class(data) == "datlist" ){
+	if ( class(data) == "datlist" ){
 		is_dfr <- FALSE
-		if ( ! base::is.null(vars) ){
-			M <- base::length(data)
+		if ( ! is.null(vars) ){
+			M <- length(data)
 			for (ii in 1:M){
 			    dat0 <- data[[ii]]
 				data[[ii]] <- dat0[ , vars, drop=FALSE ]		
@@ -50,13 +50,13 @@ ma.wtd.aux.data <- function(data , weights , vars = NULL ){
 
 	#--------------------
 	# conversion in case of class BIFIEdata
-	if ( base::class(data) == "BIFIEdata" ){
-	    base::requireNamespace("BIFIEsurvey")
-		if ( base::is.null(vars) ){
+	if ( class(data) == "BIFIEdata" ){
+	    requireNamespace("BIFIEsurvey")
+		if ( is.null(vars) ){
 			vars <- data$variables
 		}
 		#*** use weights
-		if ( base::is.null(weights) ){
+		if ( is.null(weights) ){
 			weights <- data$wgt
 		}						
 		if ( data$cdata){
@@ -65,11 +65,11 @@ ma.wtd.aux.data <- function(data , weights , vars = NULL ){
 		}
 		data <- BIFIEsurvey::BIFIE.BIFIEdata2datalist(bifieobj=data, varnames = vars)			
 		data <- datlist_create( data )
-		M <- base::length(data)
+		M <- length(data)
 		for (ii in 1:M){
 			data[[ii]][ , "one"] <- NULL
 		}
-		base::attr(data,"nvars") <- base::ncol(data[[ii]])
+		attr(data,"nvars") <- ncol(data[[ii]])
 		is_dfr <- FALSE		
 	}
 						
@@ -77,20 +77,20 @@ ma.wtd.aux.data <- function(data , weights , vars = NULL ){
 	# conversion in case of a data frame
 	if ( is_dfr ){
 	    data0 <- data
-		data0 <- base::as.matrix(data0)
-		if ( ! base::is.null(vars) ){
+		data0 <- as.matrix(data0)
+		if ( ! is.null(vars) ){
 			data0 <- data0[ , vars , drop=FALSE ]
 		}			
-		data <- base::list(1)
+		data <- list(1)
 		data[[1]] <- data0
 	}
 	#-------------------
 	# creation of weights (if needed)
-	if ( base::is.null(weights) ){
-		weights <- base::rep(1 , base::nrow(data[[1]] ) )
+	if ( is.null(weights) ){
+		weights <- rep(1 , nrow(data[[1]] ) )
 	}
-	res <- base::list( data = data , weights = weights )
-	base::return(res)
+	res <- list( data = data , weights = weights )
+	return(res)
 }
 #########################################################	
 
