@@ -5,24 +5,24 @@ mice.impute.2l.latentgroupmean.ML <- function (y, ry, x, type ,
     # latent group mean
     cluster <- as.numeric( x[ , type == - 2] )
     covariates <- as.matrix( x[ , type == 1 ] )
-    base::colnames(covariates) <- base::colnames(x)[ type == 1 ]
+    colnames(covariates) <- colnames(x)[ type == 1 ]
     y <- x[ , type == 2 ]
     # distinguish cases with and without covariates
-    if ( base::sum( type == 1 ) > 0){ 
-        cov2 <- base::cbind( cluster , covariates )
+    if ( sum( type == 1 ) > 0){ 
+        cov2 <- cbind( cluster , covariates )
         # aggregate covariates
         covaggr <- mice.impute.2l.groupmean( y , ry , x = cov2 , 
-						type = base::c(-2 , base::rep(1, base::ncol(covariates) ) ) ,
+						type = c(-2 , rep(1, ncol(covariates) ) ) ,
 						grmeanwarning=FALSE )
-        base::colnames(covaggr) <- base::colnames(covariates)
+        colnames(covaggr) <- colnames(covariates)
         # aggregation at level 2
-        covaggr.l2 <- stats::aggregate( covaggr , base::list( cluster ) , base::mean )
-        base::colnames(covaggr.l2)[-1] <- base::colnames(covaggr)
-        y.l2 <- stats::aggregate( y , base::list( cluster ) , base::mean , na.rm=TRUE )
+        covaggr.l2 <- stats::aggregate( covaggr , list( cluster ) , mean )
+        colnames(covaggr.l2)[-1] <- colnames(covaggr)
+        y.l2 <- stats::aggregate( y , list( cluster ) , mean , na.rm=TRUE )
         h1 <- as.matrix(covaggr.l2[,-1] )
-        base::colnames(h1) <- base::colnames(covaggr)
+        colnames(h1) <- colnames(covaggr)
         # PLS interactions and quadratics
-		res <- mice_imputation_get_states(pos = base::parent.frame(n=1) )	
+		res <- mice_imputation_get_states(pos = parent.frame(n=1) )	
 		vname <- res$vname
 		newstate <- res$newstate					
         plsout <- mice_imputation_pls_helper( newstate = newstate , vname = vname , 
@@ -32,9 +32,9 @@ mice.impute.2l.latentgroupmean.ML <- function (y, ry, x, type ,
                         interactions = interactions, quadratics = quadratics ,  
 						pls.facs = pls.facs ,  ... )
         # imputation PLS
-        if( ! base::is.null( plsout$yimp  ) ){ 
-            covaggr.l2r <- base::as.matrix(plsout$yimp[,-1])
-            covaggr <- base::as.matrix( covaggr.l2r[ base::match(cluster,covaggr.l2[,1]),])
+        if( ! is.null( plsout$yimp  ) ){ 
+            covaggr.l2r <- as.matrix(plsout$yimp[,-1])
+            covaggr <- as.matrix( covaggr.l2r[ match(cluster,covaggr.l2[,1]),])
         }		
         mod <- lme4::lmer( y ~ as.matrix( covaggr  ) + ( 1 | cluster ) )
     } else {
@@ -44,10 +44,10 @@ mice.impute.2l.latentgroupmean.ML <- function (y, ry, x, type ,
     modr <- modr$cluster	
 	modf <- mod@resp$mu		
     # extract cluster indices
-    a1 <- stats::aggregate( modf , base::list( cluster) , base::mean )
-    a1[,3] <-  base::sqrt( base::attr( modr , "postVar" )[1,1,] )
+    a1 <- stats::aggregate( modf , list( cluster) , mean )
+    a1[,3] <-  sqrt( attr( modr , "postVar" )[1,1,] )
     # match cluster indices
-    ind <- base::match( cluster , a1[,1] )
+    ind <- match( cluster , a1[,1] )
     ximp <- stats::rnorm( nrow(a1) , mean = a1[,2] ,  sd = (1-EAP)*a1[,3] )[ ind ]
-    base::return(ximp)
+    return(ximp)
 }
