@@ -2,8 +2,8 @@
 ########################################################################
 # draw binomial data
 mice_multilevel_draw_binomial <- function( probs ){	
-	N <- base::length(probs)
+	N <- length(probs)
 	rn <- stats::runif(N, 0, 1)
 	res <- 1*(rn < probs)
-	base::return(res)
-}
\ No newline at end of file
+	return(res)
+}
