@@ -5,7 +5,7 @@
 # This function reads fwf files                                            #
 read.fwf2 <- function( file , format.full , variables = NULL){
 	format <- format.full
-    ff <- base::readLines( file )
+    ff <- readLines( file )
     ind.ff1 <- c( 1, cumsum(format)[- length(format) ] + 1 )
     ind.ff2 <- cumsum(format)
     I <- length(format)
@@ -17,4 +17,4 @@ read.fwf2 <- function( file , format.full , variables = NULL){
     if (!is.null(variables)){ colnames(dfr) <- variables }
     return(dfr)
     } 
-############################################################################
\ No newline at end of file
+############################################################################
